@@ -1,5 +1,6 @@
 # -*- coding: UTF-8 -*-
 import logging
+import re
 import sys
 from argparse import ArgumentParser, RawTextHelpFormatter
 from os.path import exists
@@ -29,15 +30,17 @@ def main():
     parser = ArgumentParser(description=descr, epilog=examples, formatter_class=RawTextHelpFormatter, add_help=False)
     parser.add_argument("path", type=valid_file, help="path to portable executable")
     opt = parser.add_argument_group("optional arguments")
+    opt.add_argument("-a", "--author", action="store_true", help="include author in the result")
     opt.add_argument("-d", "--db", default=DB, type=valid_file,
                      help="path to the custom database of signatures (default: None ; use the embedded DB)")
     opt.add_argument("-e", "--ep-only", action="store_false",
                      help="consider only entry point signatures (default: True)")
+    opt.add_argument("-v", "--version", action="store_true", help="include the version in the result")
     extra = parser.add_argument_group("extra arguments")
     extra.add_argument("-b", "--benchmark", action="store_true",
                        help="enable benchmarking, output in seconds (default: False)")
     extra.add_argument("-h", "--help", action="help", help="show this help message and exit")
-    extra.add_argument("-v", "--verbose", action="store_true", help="display debug information (default: False)")
+    extra.add_argument("--verbose", action="store_true", help="display debug information (default: False)")
     args = parser.parse_args()
     logging.basicConfig()
     args.logger = logging.getLogger("peid")
@@ -48,6 +51,13 @@ def main():
         t1 = perf_counter()
     try:
         r = identify_packer(args.path, args.db, args.ep_only, args.logger)
+        if not args.author:
+            r = list(map(lambda x: re.sub(r"\s*\-(\-?\>|\s*by)\s*(.*)$", "", x), r))
+        if not args.version:
+            VER = r"\s*([vV](ersion)?|R)?\s?(20)?\d{1,2}(\.[xX0-9]{1,3}([a-z]?\d)?){0,3}[a-zA-Z\+]?" \
+                  r"(\s*\(?(\s*([Aa]lpha|[Bb]eta|final|lite|LITE|osCE|Demo|DEMO)){1,2}(\s*[a-z]?\d)?\)?)?"
+            VER = re.compile(r"^(.*?)\s+" + VER + r"(\s*[-_\/\~]" + VER + r"){0,3}(\s+\(unregistered\))?")
+            r = list(map(lambda x: re.sub(r"\s+\d+(\s+SE)?$", "", VER.sub(r"\1", x)), r))
         dt = str(perf_counter() - t1) if args.benchmark else ""
         if dt != "":
             r.append(dt)
